/**
 * Clean Framework Adapters SDK Implementation
 * @iota-big3/sdk-adapters
 */
import { FrameworkAdapter } from './adapter-manager';
import { AdapterConfig, ExpressConfig, FastifyConfig, FrameworkType, KoaConfig, Middleware } from './types';
export interface EventBusLike {
    emit(event: string, data: any): void;
    on(event: string, handler: (data: any) => void): void;
    off(event: string, handler: (data: any) => void): void;
}
export interface LoggerLike {
    info(message: string, meta?: any): void;
    warn(message: string, meta?: any): void;
    error(message: string, meta?: any): void;
    debug(message: string, meta?: any): void;
}
export interface CacheLike {
    get<T>(key: string): Promise<T | null>;
    set(key: string, value: any, ttl?: number): Promise<boolean>;
    delete(key: string): Promise<boolean>;
    exists(key: string): Promise<boolean>;
}
export interface ConfigLike {
    get<T>(key: string): T;
    set(key: string, value: any): void;
    has(key: string): boolean;
}
export interface SecurityLike {
    validateRequest(req: any): Promise<boolean>;
    sanitizeInput<T>(data: T): T;
    checkPermissions(user: any, resource: string, action: string): Promise<boolean>;
}
export interface RealtimeLike {
    createNamespace(name: string): any;
    handleUpgrade(request: any, socket: any, head: any): void;
}
export interface AdaptersSDKOptions {
    eventBus?: EventBusLike;
    logger?: LoggerLike;
    cache?: CacheLike;
    config?: ConfigLike;
    security?: SecurityLike;
    realtime?: RealtimeLike;
    defaultFramework?: FrameworkType;
    enableMetrics?: boolean;
    enableLogging?: boolean;
}
export { AdapterManager, AdapterRegistry, ExpressAdapter, FastifyAdapter, FrameworkAdapter, KoaAdapter } from './adapter-manager';
export * from './types';
export { FrameworkAdaptersSDK } from './framework-adapters-sdk';
export declare function createAdapter(framework: FrameworkType, config?: AdapterConfig): FrameworkAdapter;
export declare function getAdapter<T extends FrameworkAdapter>(framework: FrameworkType): T | undefined;
export declare function getSupportedFrameworks(): FrameworkType[];
export declare function createExpressConfig(overrides?: Partial<ExpressConfig>): ExpressConfig;
export declare function createFastifyConfig(overrides?: Partial<FastifyConfig>): FastifyConfig;
export declare function createKoaConfig(overrides?: Partial<KoaConfig>): KoaConfig;
export declare const FrameworkTemplates: {
    express: {
        basic: (config?: Partial<ExpressConfig>) => ExpressConfig;
        api: (config?: Partial<ExpressConfig>) => ExpressConfig;
        secure: (config?: Partial<ExpressConfig>) => ExpressConfig;
    };
    fastify: {
        basic: (config?: Partial<FastifyConfig>) => FastifyConfig;
        api: (config?: Partial<FastifyConfig>) => FastifyConfig;
        performance: (config?: Partial<FastifyConfig>) => FastifyConfig;
    };
    koa: {
        basic: (config?: Partial<KoaConfig>) => KoaConfig;
        api: (config?: Partial<KoaConfig>) => KoaConfig;
        minimal: (config?: Partial<KoaConfig>) => KoaConfig;
    };
};
export declare const MiddlewareHelpers: {
    cors: (options?: Record<string, unknown>) => Middleware;
    helmet: (options?: Record<string, unknown>) => Middleware;
    logger: (options?: Record<string, unknown>) => Middleware;
    rateLimit: (options?: Record<string, unknown>) => Middleware;
    compression: (options?: Record<string, unknown>) => Middleware;
    errorHandler: (options?: Record<string, unknown>) => Middleware;
};
export declare const SDK_VERSION = "1.0.0";
export declare const SDK_NAME = "@iota-big3/sdk-adapters";
//# sourceMappingURL=index.d.ts.map